import 'dart:async';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

const MethodChannel _channel = const MethodChannel('passbase_flutter');

class PassbaseSDK {
  static set prefillUserEmail(String value) {
    assert(value != null, "prefillUserEmail cannot be null!");
    _channel.invokeMethod('setPrefillUserEmail', value);
  }

  static Future<void> initialize({@required String publishableApiKey}) async {
    assert(publishableApiKey != null, "API key cannot be null!");

    await _channel.invokeMethod('initialize', publishableApiKey);
    return;
  }

  static Future<void> startVerification({
    Function onStart,
    Function(String authenticationKey) onFinish,
    Function(String errorCode) onError,
  }) async {
    _channel.setMethodCallHandler((call) {
      if (call.method == "verification_error") {
        onError(call.arguments.toString());
      } else if (call.method == "verification_complete") {
        onFinish(call.arguments.toString());
      } else if (call.method == "verification_start") {
        onStart();
      }
      return;
    });

    await _channel.invokeMethod('startVerification');
  }
}

class PassbaseButton extends StatelessWidget {
  final double width;
  final double height;
  final Function(String authenticationKey) onFinish;
  final Function(String errorCode) onError;
  final Function onStart;

  PassbaseButton(
      {this.width, this.height, this.onFinish, this.onError, this.onStart}) {
    _channel.setMethodCallHandler((call) {
      if (call.method == "verification_error") {
        onError(call.arguments.toString());
      } else if (call.method == "verification_complete") {
        onFinish(call.arguments.toString());
      } else if (call.method == "verification_start") {
        onStart();
      }
      return;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      height: height,
      child: Platform.isAndroid
          ? AndroidView(
              viewType: "PassbaseButton",
            )
          : UiKitView(
              viewType: "PassbaseButton",
            ),
    );
  }
}
